<?php

namespace Drupal\mailjet;

/**
 * Interface for mailjet handler.
 */
interface MailjetHandlerInterface {

  public const CONFIG_NAME = 'mailjet.settings';

  /**
   * Get contact list for Mailjet.
   *
   * @param int $limit
   *   Contain limit of list item.
   */
  public function getMailjetContactLists($limit = 0);

  /**
   * Get mailjet contacts by name.
   *
   * @param string $name
   *   Name of contact.
   */
  public function getMailjetContactListByName($name);

  /**
   * Get contact properties.
   *
   * @param int $limit
   *   Contain limit of list item.
   */
  public function getMailjetContactProperties($limit = 0);

  /**
   * Create response with contacts list.
   *
   * @param string $listName
   *   Contain list name.
   */
  public function createMailjetContactList($listName);

  /**
   * Get contact properties.
   */
  public function getContactProperties();

  /**
   * Create response with contact properties.
   *
   * @param string $name
   *   Contain contact name.
   * @param string $type
   *   Contain contact type.
   */
  public function createMailjetContactProperty($name, $type = "str");

  /**
   * Create response with update of contact properties.
   *
   * @param int $id
   *   Contain contact id.
   * @param string $name
   *   Contain contact name.
   * @param string $type
   *   Contain contact type.
   */
  public function updateMailjetContactProperty($id, $name, $type = "str");

  /**
   * Sync of Contacts.
   *
   * @param int $contactListId
   *   Contain contact list id.
   * @param array $contacts
   *   Contain contacts.
   * @param string $action
   *   Contain action name.
   */
  public function syncMailjetContacts($contactListId, array $contacts, $action = 'addforce');

  /**
   * Sync of Contact.
   *
   * @param int $contactListId
   *   Contain contact list id.
   * @param array $contact
   *   Contain contacts.
   * @param string $action
   *   Contain action name.
   */
  public function syncMailjetContact($contactListId, array $contact, $action = 'addforce');

  /**
   * Crate api key.
   *
   * @param array $params
   *   Contain params for creating api token.
   */
  public function createApiToken(array $params);

}
